@@ -17,22 +17,23 @@ def handleSurveyUnpublish(survey, event):
     """Event handler (subscriber) to take care of unpublishing a survey
     from the client.
     """
-    surveygroup=aq_parent(survey)
-    sector=aq_parent(surveygroup)
-    country=aq_parent(sector)
+    surveygroup = aq_parent(survey)
+    sector = aq_parent(surveygroup)
+    country = aq_parent(sector)
 
-    pas=getToolByName(survey, "acl_users")
-    clientuser=pas.getUserById("client")
-    sm=getSecurityManager()
+    pas = getToolByName(survey, "acl_users")
+    clientuser = pas.getUserById("client")
+    sm = getSecurityManager()
     try:
         newSecurityManager(None, clientuser)
-        client=getPortal(survey).client
+        client = getPortal(survey).client
         try:
-            clientcountry=client[country.id]
-            clientsector=clientcountry[sector.id]
+            clientcountry = client[country.id]
+            clientsector = clientcountry[sector.id]
             clientsector[surveygroup.id]
         except KeyError:
-            log.info("Trying to unpublish unpublished survey %s", "/".join(survey.getPhysicalPath()))
+            log.info("Trying to unpublish unpublished survey %s",
+                    "/".join(survey.getPhysicalPath()))
             return
 
         clientsector.manage_delObjects([surveygroup.id])
@@ -40,4 +41,3 @@ def handleSurveyUnpublish(survey, event):
             clientcountry.manage_delObjects([clientsector.id])
     finally:
         setSecurityManager(sm)
-
